package
Version:
v0.0.0-...-86399fd
Opens a new window with list of versions in this module.
Published: Dec 7, 2021
License: MPL-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Environment string
Mongo config
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.